@@ -1,3 +1,4 @@
+package SHARYANTO::YAML::Any_YAMLAny;
 package SHARYANTO::YAML::Any;
 
 # NOTE: temporary namespace, will eventually be refactored, tidied up, and sent
@@ -133,13 +134,15 @@ sub croak {
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-SHARYANTO::YAML::Any
+SHARYANTO::YAML::Any_YAMLAny
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -157,13 +160,8 @@ rest is YAML::Any's documentation.
 There are several YAML implementations that support the Dump/Load API.
 This module selects the best one available and uses it.
 
-=head1 NAME
 
-SHARYANTO::YAML::Any - Pick a YAML implementation and use it.
-
-=head1 VERSION
-
-version 0.72
+This module has L<Rinci> metadata.
 
 =head1 ORDER
 
@@ -220,11 +218,11 @@ C<require>. If no implementation is found, an error will be thrown.
 
 =back
 
-=head1 AUTHOR
+=head1 ORIGINAL AUTHOR
 
 Ingy döt Net <ingy@cpan.org>
 
-=head1 COPYRIGHT
+=head1 ORIGINAL COPYRIGHT
 
 Copyright (c) 2008. Ingy döt Net.
 
@@ -239,22 +237,16 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Steven Haryanto.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 AUTHOR
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
 This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
 =cut
 
 
